@@ -4,6 +4,7 @@ use Mojo::Base 'Mojo::EventEmitter';
 use DBD::Pg ':async';
 use IO::Handle;
 use Mojo::IOLoop;
+use Mojo::JSON 'encode_json';
 use Mojo::Pg::Results;
 use Mojo::Pg::Transaction;
 use Scalar::Util 'weaken';
@@ -40,7 +41,7 @@ sub do {
   return $self;
 }
 
-sub dollar_only { ++$_[0]->{dollar_only} and return $_[0] }
+sub dollar_only { ++$_[0]{dollar_only} and return $_[0] }
 
 sub is_listening { !!keys %{shift->{listen} || {}} }
 
@@ -70,6 +71,9 @@ sub query {
   my ($self, $query) = (shift, shift);
   my $cb = ref $_[-1] eq 'CODE' ? pop : undef;
 
+  # JSON
+  my @values = map { _json($_) ? encode_json $_->{json} : $_ } @_;
+
   # Dollar only
   my $dbh = $self->dbh;
   local $dbh->{pg_placeholder_dollaronly} = 1 if delete $self->{dollar_only};
@@ -77,14 +81,14 @@ sub query {
   # Blocking
   unless ($cb) {
     my $sth = $dbh->prepare($query);
-    $sth->execute(@_);
+    $sth->execute(@values);
     $self->_notifications;
     return Mojo::Pg::Results->new(sth => $sth);
   }
 
   # Non-blocking
   my $sth = $dbh->prepare($query, {pg_async => PG_ASYNC});
-  push @{$self->{waiting}}, {args => [@_], cb => $cb, sth => $sth};
+  push @{$self->{waiting}}, {args => \@values, cb => $cb, sth => $sth};
   $self->$_ for qw(_next _watch);
 }
 
@@ -100,6 +104,8 @@ sub unlisten {
   return $self;
 }
 
+sub _json { ref $_[0] eq 'HASH' && (keys %{$_[0]})[0] eq 'json' }
+
 sub _next {
   return unless my $next = shift->{waiting}[0];
   $next->{sth}->execute(@{$next->{args}}) unless $next->{executed}++;
@@ -251,9 +257,8 @@ Execute a statement and discard its result.
 Activate C<pg_placeholder_dollaronly> for next L</"query"> call and allow C<?>
 to be used as an operator.
 
-  use Mojo::JSON 'decode_json';
   $db->dollar_only->query('select * from foo where bar ? $1', 'baz')
-    ->hashes->map(sub { json_decode($_->{bar})->{baz} })->join("\n")->say;
+    ->expand->hashes->map(sub { $_->{bar}{baz} })->join("\n")->say;
 
 =head2 is_listening
 
@@ -291,6 +296,7 @@ Check database connection.
 
   my $results = $db->query('select * from foo');
   my $results = $db->query('insert into foo values (?, ?, ?)', @values);
+  my $results = $db->query('select ?::json as foo', {json => {bar => 'baz'}});
 
 Execute a blocking statement and return a L<Mojo::Pg::Results> object with the
 results. You can also append a callback to perform operation non-blocking.
